==> apache-servicecomb-java-chassis-distribution-1.3.11-src.zip: apache-servicecomb-java-chassis-distribution-1.3.11-src/core/src/main/java/org/apache/servicecomb/core/bootup/ServiceInformationCollector.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.core.bootup;

import org.apache.servicecomb.serviceregistry.RegistryUtils;

public class ServiceInformationCollector implements BootUpInformationCollector {


  @Override
  public String collect() {
    return "App ID: " + RegistryUtils.getMicroservice().getAppId()
        + "\n" + "Service Name: " + RegistryUtils.getMicroservice().getServiceName()
        + "\n" + "Version: " + RegistryUtils.getMicroservice().getVersion()
        + "\n" + "Environment: " + RegistryUtils.getMicroservice().getEnvironment()
        + "\n" + "Service ID: " + RegistryUtils.getMicroserviceInstance().getServiceId()
        + "\n" + "Instance ID: " + RegistryUtils.getMicroserviceInstance().getInstanceId();
  }

  @Override
  public int getOrder() {
    return 200;
  }
}

==> apache-servicecomb-java-chassis-distribution-3.2.2-src.zip: apache-servicecomb-java-chassis-distribution-3.2.2-src/core/src/main/java/org/apache/servicecomb/core/bootup/ServiceInformationCollector.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.core.bootup;

import org.apache.servicecomb.registry.DiscoveryManager;
import org.apache.servicecomb.registry.RegistrationManager;
import org.springframework.beans.factory.annotation.Autowired;

public class ServiceInformationCollector implements BootUpInformationCollector {
  private RegistrationManager registrationManager;

  private DiscoveryManager discoveryManager;

  public ServiceInformationCollector() {
  }

  @Autowired
  public void setRegistrationManager(RegistrationManager registrationManager) {
    this.registrationManager = registrationManager;
  }

  @Autowired
  public void setDiscoveryManager(DiscoveryManager discoveryManager) {
    this.discoveryManager = discoveryManager;
  }

  @Override
  public String collect() {
    return registrationManager.info() + "\n" + discoveryManager.info();
  }

  @Override
  public int getOrder() {
    return 200;
  }
}
